@@ -1,10 +1,10 @@
-from webbrowser import open as open_url
-
 from click import command, argument, option
-from click.exceptions import UsageError
-from cloudinary import uploader as _uploader
+from cloudinary import uploader
 
-from cloudinary_cli.utils import logger, get_help, parse_args_kwargs, parse_option_value, write_out, log_json
+from cloudinary_cli.core.overrides import upload
+from cloudinary_cli.utils.api_utils import handle_api_command
+
+uploader.upload = upload
 
 
 @command("uploader",
@@ -27,24 +27,7 @@ Format: cld <cli options> uploader <command options> <method> <method parameters
 @option("--save", nargs=1, help="Save output to a file.")
 @option("-d", "--doc", is_flag=True, help="Open the Upload API reference in a browser.")
 def uploader(params, optional_parameter, optional_parameter_parsed, ls, save, doc):
-    if doc:
-        open_url("https://cloudinary.com/documentation/image_upload_api_reference")
-        return
-    if ls or len(params) < 1:
-        logger.info(get_help(_uploader))
-        return
-    try:
-        func = _uploader.__dict__[params[0]]
-        if not callable(func):
-            raise UsageError("{} is not callable.".format(func))
-    except Exception as e:
-        raise e
-    parameters, options = parse_args_kwargs(func, params[1:]) if len(params) > 1 else ([], {})
-    res = func(*parameters, **{
-        **options,
-        **{k: v for k, v in optional_parameter},
-        **{k: parse_option_value(v) for k, v in optional_parameter_parsed},
-    })
-    log_json(res)
-    if save:
-        write_out(res, save)
+    return handle_api_command(params, optional_parameter, optional_parameter_parsed, ls, save, doc,
+                              doc_url="https://cloudinary.com/documentation/image_upload_api_reference",
+                              api_instance=uploader,
+                              api_name="upload")
